"""
NAWA‑Tracking - Smart Pilgrim AI Toolkit
"""
__version__ = "0.1.0"
__codename__ = "O3"      # codename اختياري داخلي

from .matcher import simulate_match
from .behavior import analyze_behavior
from .report import build_pdf
